@@ -3,18 +3,20 @@ import requests
 from .onfido_download import OnfidoDownload
 from .exceptions import error_decorator, OnfidoUnknownError
 from .mimetype import mimetype_from_name
+from .utils import flat_nested_dict
+
 
 CURRENT_VERSION = pkg_resources.get_distribution("onfido-python").version
 
 class Resource:
-    def __init__(self, api_token, base_url, timeout):
+    def __init__(self, api_token, region, timeout):
         self._api_token = api_token
-        self._base_url = base_url
+        self._region = region
         self._timeout = timeout
 
     @property
     def _url(self):
-        return getattr(self._base_url, "region_url", self._base_url)
+        return getattr(self._region, "region_url", self._region)
 
     def _build_url(self, path):
         return self._url + path
@@ -42,7 +44,7 @@ class Resource:
             'file': (file.name, file, mimetype_from_name(file.name))
         }
         
-        response = requests.post(self._build_url(path), data=request_body,
+        response = requests.post(self._build_url(path), data=flat_nested_dict(request_body),
                                  files=files, headers=self._headers, timeout=self._timeout)
 
         return self._handle_response(response)
@@ -76,9 +78,8 @@ class Resource:
         except ValueError as e:
             raise OnfidoUnknownError("Onfido returned invalid JSON") from e
 
-
     @error_decorator
     def _delete_request(self, path):
         response = requests.delete(self._build_url(path), headers=self._headers, timeout=self._timeout)
 
-        return self._handle_response(response)
\ No newline at end of file
+        return self._handle_response(response)
